@@ -1,13 +1,12 @@
-from pyfrigel_report_tool.consts import DEFAULT_STROKE_COLOR, WORKING_MODES_COLORS, DEFAULT_FONT
+from pyfrigel_report_tool.consts import DEFAULT_STROKE_COLOR, WORKING_MODES_COLORS, DEFAULT_FONT, DEFAULT_ON_COLOR, DEFAULT_NEGATIVE_COLOR
 
-from reportlab.graphics.shapes import Drawing, _DrawingEditorMixin
+from reportlab.graphics.shapes import Drawing, _DrawingEditorMixin, Polygon
 from reportlab.graphics.charts.legends import Legend
 from reportlab.graphics.charts.piecharts import Pie
-from reportlab.graphics.charts.barcharts import VerticalBarChart
+from reportlab.graphics.charts.barcharts import VerticalBarChart, HorizontalBarChart
 from reportlab.lib.colors import PCMYKColor
 from reportlab.lib.formatters import DecimalFormatter
 
-
 class ChartPieWithLegend(_DrawingEditorMixin, Drawing):
     '''
         creates a pie chart with a legend
@@ -26,9 +25,8 @@ class ChartPieWithLegend(_DrawingEditorMixin, Drawing):
         self.pie.slices.strokeWidth = 0
         self._seriesNames = seriesNames
         self._add(self, Legend(), name='legend', validate=None, desc=None)
-        self.legend.y = self.height/2
-        self.legend.columnMaximum  = 6
-        self.legend.y = self.height/2 + 10
+        self.legend.columnMaximum  = 3
+        self.legend.y = self.height/2 +10
         self.legend.x = 120
         self.legend.fontName = DEFAULT_FONT
         self.legend.strokeWidth = 0
@@ -52,7 +50,7 @@ class ChartBar(_DrawingEditorMixin,Drawing):
             height (float)
             
     """
-    def __init__(self, data: list, category_names: list, colors: list, width=500, height=200, style='parallel', *args, **kw):
+    def __init__(self, data: list, category_names: list, colors: list, width=400, height=200, style='stacked', legend = False, series_names=None, *args, **kw):
         Drawing.__init__(self,width,height,*args,**kw)
         self._add(self,VerticalBarChart(),name='chart',validate=None,desc=None)
         self.chart.x = 30
@@ -68,12 +66,46 @@ class ChartBar(_DrawingEditorMixin,Drawing):
         self.chart.valueAxis.valueMax = 24
         self.chart.valueAxis.valueStep= 6
         self.chart.valueAxis.labelTextFormat= '%0.0f h'
+        self.chart.valueAxis.labels.fontName = DEFAULT_FONT
+        self.chart.categoryAxis.labels.fontName = DEFAULT_FONT
         self.chart.data = data
         for index, color in enumerate(colors): self.chart.bars[index].fillColor = color 
+        if legend:
+            self._colors = WORKING_MODES_COLORS
+            self._add(self, Legend(), name='legend', validate=None, desc=None)
+            self.legend.x = 400
+            self.legend.y = 180
+            self.legend.fontSize = 8
+            self.legend.fontName = DEFAULT_FONT
+            self.legend.dx = 8
+            self.legend.dy = 8
+            self.legend.dxTextSpace = 10
+            self.legend.yGap = 0
+            self.legend.deltay = 24
+            self.legend.strokeColor = PCMYKColor(0,0,0,0)
+            self.legend.strokeWidth = 0
+            self.legend.columnMaximum = 99
+            self.legend.alignment = 'right'
+            self.legend.variColumn = 0
+            self.legend.dividerDashArray = None
+            self.legend.dividerWidth = 0.25
+            self.legend.subCols[0].align = 'left'
+            self.legend.subCols[0].minWidth = 200
+            self.legend.subCols[1].align = 'right'
+            self.legend.subCols[1].align='numeric'
+            self.legend.subCols[1].dx = -30
+            self.legend.subCols[1].minWidth = 80
+            self.legend.subCols[2].align = 'right'
+            self.legend.subCols[2].align='numeric'
+            self.legend.subCols[2].dx = -10
+            self.legend.subCols[2].minWidth = 16
+            self._seriesNames = series_names
+            names = list(zip(self._seriesNames))
+            self.legend.colorNamePairs = list(zip(self._colors, names))
         self.chart.bars.strokeWidth = 0.25
         self.chart.bars.strokeColor = DEFAULT_STROKE_COLOR
         self.chart.categoryAxis.categoryNames = category_names
-        
+
 
 class PieChartWorkingModes(_DrawingEditorMixin,Drawing):
     """
@@ -87,7 +119,7 @@ class PieChartWorkingModes(_DrawingEditorMixin,Drawing):
             height (float)
             
     """
-    def __init__(self, data, data_trend, header_names: tuple, series_names: tuple, width=500, height=125, *args, **kw):
+    def __init__(self, data, label_percentage, data_trend, header_names: tuple, series_names: tuple, width=400, height=125, *args, **kw):
         Drawing.__init__(self,width,height,*args,**kw)
         self._colors = WORKING_MODES_COLORS
         # font
@@ -103,11 +135,11 @@ class PieChartWorkingModes(_DrawingEditorMixin,Drawing):
         self.chart.slices.strokeWidth = 0.5
         self._add(self, Legend(), name='legend', validate=None, desc=None)
         self._add(self, Legend(), name='legendHeader', validate=None, desc=None)
-        self.legendHeader.x = 150
-        self.legendHeader.y = self.height - 10
+        self.legendHeader.x = 130
+        self.legendHeader.y = self.height -25
         self.legendHeader.fontSize = fontSize
         self.legendHeader.fontName = fontName
-        self.legendHeader.subCols[0].minWidth = 200
+        self.legendHeader.subCols[0].minWidth = 190
         self.legendHeader.subCols[0].align = 'left'
         self.legendHeader.subCols[1].minWidth = 80
         self.legendHeader.subCols[1].align = 'right'
@@ -116,8 +148,8 @@ class PieChartWorkingModes(_DrawingEditorMixin,Drawing):
         self.legendHeader.subCols[3].minWidth = 1000 # needed to remove black rectangle
         black = PCMYKColor(0, 0, 0, 100)
         self.legendHeader.colorNamePairs = [(black, header_names + ('', ))]
-        self.legend.x = 150
-        self.legend.y = 90
+        self.legend.x = 130
+        self.legend.y = self.height -50
         self.legend.fontSize = fontSize
         self.legend.fontName = fontName
         self.legend.dx = 8
@@ -136,29 +168,89 @@ class PieChartWorkingModes(_DrawingEditorMixin,Drawing):
         self.legend.dividerLines = 7
         self.legend.dividerOffsY = 12
         self.legend.subCols[0].align = 'left'
-        self.legend.subCols[0].minWidth = 200
+        self.legend.subCols[0].minWidth = 190
         self.legend.subCols[1].align = 'right'
         self.legend.subCols[1].align='numeric'
         self.legend.subCols[1].dx = -30
-        self.legend.subCols[1].minWidth = 80
+        self.legend.subCols[1].minWidth = 90
         self.legend.subCols[2].align = 'right'
         self.legend.subCols[2].align='numeric'
         self.legend.subCols[2].dx = -10
-        self.legend.subCols[2].minWidth = 160
+        self.legend.subCols[2].minWidth = 137
         # sample data
         self._seriesNames = series_names
         self._seriesData1 = data
         self._seriesData2 = data_trend
-        formatter_time = DecimalFormatter(places=1, thousandSep=',', decimalSep='.', suffix=' h')
+        up = Drawing(3,3).add(Polygon(
+                    strokeColor = DEFAULT_ON_COLOR,
+                    fillColor = DEFAULT_ON_COLOR,
+                    points=[4, 6+(5/2), 4-(5/2), 6-(5/2), 4+(5/2), 6-(5/2), 4, 6+(5/2)] #Structure [(x1,y1),(x2,y2),...]
+                ))
+        down = Drawing(3,3).add(Polygon(
+                    strokeColor = DEFAULT_NEGATIVE_COLOR,
+                    fillColor = DEFAULT_NEGATIVE_COLOR,
+                    points=[4, 6-(5/2), 4+(5/2), 6+(5/2), 4-(5/2), 6+(5/2), 4, 6-(5/2)] 
+                ))
+
+
+        formatter_time = DecimalFormatter(places=0, thousandSep=',', decimalSep='.', suffix=' h')
         formatter_trend = lambda x: DecimalFormatter(places=0, thousandSep=',', decimalSep='.', suffix=' %').format(x) if x != None else x
-        sign_adder = lambda x: '-' if x== None else x if x.startswith('-') else '+{}'.format(x)
+        sign_adder = lambda x: '-' if x== None else down if x.startswith('-') else up
         names = list(zip(self._seriesNames,
         map(formatter_time, self._seriesData1),
         map(sign_adder, map(formatter_trend, self._seriesData2))))
         self.legend.colorNamePairs = list(zip(self._colors, names))
         self.chart.data  = self._seriesData1
+        self.chart.labels = label_percentage
+        self.chart.slices.fontName = DEFAULT_FONT
         # apply colors to slices
         for i, _ in enumerate(self.chart.data): self.chart.slices[i].fillColor = self._colors[i]
         self.legend.deltax = 75
         self.legendHeader.subCols[0].minWidth = 100
-        self.legend.subCols[0].minWidth = 90
\ No newline at end of file
+        self.legend.subCols[0].minWidth = 100
+
+class HBarChartValueAxisNegLabels(_DrawingEditorMixin,Drawing):
+    
+    '''
+Chart Features
+--------------
+This is a simple horizontal barchart whose XVAlueAxis is modified to make the negative tick labels turn red.
+
+        - The xValueAxis has negative tick labels coloured red. That is accomplished by changing the Label attribute customDrawChanger to be an instance of
+        reportlab.graphics.charts.textlabels.RedNegativeChanger.
+
+        This chart was built with our [Diagra](http://www.reportlab.com/software/diagra/) solution.
+
+        Not the kind of chart you looking for? Go [up](..) for more charts, or to see different types of charts click on [ReportLab Charts Gallery](/chartgallery/).
+    '''
+    def __init__(self, data: list, category_names: list, width=500, height=200, style='parallel', *args, **kw):
+        Drawing.__init__(self,width,height,*args,**kw)
+        self._add(self,HorizontalBarChart(),name='chart',validate=None,desc=None)
+        self.chart.x = 30
+        self.chart.y = 20
+        self.chart.width=self.width - self.chart.x -10
+        self.chart.height=self.height - self.chart.y -10
+        self.chart.reversePlotOrder = 0
+        self.chart.valueAxis.strokeWidth = 0.5
+        self.chart.categoryAxis.strokeWidth = 0.5
+        self.chart.valueAxis.valueMin = -500
+        self.chart.valueAxis.valueMax = 500
+        self.chart.valueAxis.valueStep= 50
+        self.chart.valueAxis.labels.fontName = DEFAULT_FONT
+        self.chart.categoryAxis.labels.fontName = DEFAULT_FONT
+        self.chart.data = data
+        self.chart.bars.strokeWidth = 0.25
+        self.chart.categoryAxis.style = style
+        self.chart.categoryAxis.categoryNames = category_names
+        self.chart.valueAxis.labelTextFormat= '%0.0f sec'
+        self.chart.valueAxis.labels.angle = -45
+        self.chart.valueAxis.labels.boxAnchor ='autox'
+        for index, value in enumerate(data[0]):
+            if value >0:
+                self.chart.bars[(0, index)].fillColor = DEFAULT_ON_COLOR
+                self.chart.categoryAxis.labels[index].dx = -8
+                self.chart.categoryAxis.labels[index].dy = -2
+            else:
+                self.chart.bars[(0, index)].fillColor = DEFAULT_NEGATIVE_COLOR             
+                self.chart.categoryAxis.labels[index].dx = 10 + len(category_names[index])*4
+                self.chart.categoryAxis.labels[index].dy = -2
\ No newline at end of file
